import requests
import json
def pyInstantSend(webhookURL, message):
    stupid = {'content': message}
    requests.post(webhookURL,stupid)
def pySend():
    webhookURL = input('What is the webhook URL? ')
    message = input('Type in your message. ')
    messageToJSON = {'content': message}
    requests.post(webhookURL,messageToJSON)


from setuptools import setup, find_packages

with open('README.md', 'r') as f:
    description = f.read()
setup(
    name="pyLaysWebhooker",
    version="1.3",
    packages=find_packages(),
    entry_points={
        "console_scripts": [
            "pySend = pyLaysWebhooker:pySend",
            "pyInstantSend = pyLaysWebhooker:pyInstantSend"
        ]
    },
    long_description=description,
    long_description_content_type='text/markdown'
)